@@ -3,14 +3,14 @@ Request using TCP protocol.
 '''
 import asyncio
 import struct
+from async_dns.core import DNSMessage
 
-_DEFAULT_QUEUE_SIZE = 10
-_DEFAULT_CONNECTION_LIFETIME = 120
+DEFAULT_QUEUE_SIZE = 10
 _connections = {}
 
 class DNSConnectionError(ConnectionError):
     '''
-    Error thrown when connection to nameserver fails.
+    Connection to nameserver fails.
     '''
 
 async def request(req, addr, timeout=3.0):
@@ -19,8 +19,11 @@ async def request(req, addr, timeout=3.0):
     '''
     qdata = req.pack()
     bsize = struct.pack('!H', len(qdata))
-    key = addr.to_str(53)
-    queue = _connections.setdefault(key, asyncio.Queue(maxsize=_DEFAULT_QUEUE_SIZE))
+    key = str(addr)
+    queue = _connections.get(key)
+    if queue is None:
+        queue = asyncio.Queue(maxsize=DEFAULT_QUEUE_SIZE)
+        _connections[key] = queue
     for _retry in range(5):
         reader = writer = None
         try:
@@ -29,7 +32,7 @@ async def request(req, addr, timeout=3.0):
             pass
         if reader is None:
             try:
-                reader, writer = await asyncio.wait_for(asyncio.open_connection(addr.host, addr.port), timeout)
+                reader, writer = await asyncio.wait_for(asyncio.open_connection(*addr.to_addr()), timeout)
             except asyncio.TimeoutError:
                 pass
         if reader is None:
@@ -43,6 +46,7 @@ async def request(req, addr, timeout=3.0):
             queue.put_nowait((reader, writer))
         except asyncio.QueueFull:
             pass
-        return data
+        result = DNSMessage.parse(data)
+        return result
     else:
         raise DNSConnectionError
